import typer
from pathlib import Path
from zona import server
from zona.builder import ZonaBuilder
from zona.layout import initialize_site

app = typer.Typer()


@app.command()
def build(root: Path | None = None, output: Path | None = None):
    builder = ZonaBuilder(root, output)
    builder.build()


@app.command()
def serve(dir: Path = Path("public")):
    if not dir.exists():
        raise typer.BadParameter(f"Directory {dir} does not exist.")
    typer.echo(f"Serving files from {dir}")
    server.serve(dir)


@app.command()
def init(root: Path | None = None):
    # init will populate the current directory with
    # the required folders and their default values
    initialize_site(root)


def main():
    app()
